You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by lc...@apache.org on 2017/06/15 18:05:45 UTC

[1/2] beam git commit: [BEAM-1348] Mark Runner API like types declared within Fn API as deprecated.

Repository: beam
Updated Branches:
  refs/heads/master 6fc70b35f -> 346a77fa8


[BEAM-1348] Mark Runner API like types declared within Fn API as deprecated.

Add additional documentation.


Project: http://git-wip-us.apache.org/repos/asf/beam/repo
Commit: http://git-wip-us.apache.org/repos/asf/beam/commit/628366cd
Tree: http://git-wip-us.apache.org/repos/asf/beam/tree/628366cd
Diff: http://git-wip-us.apache.org/repos/asf/beam/diff/628366cd

Branch: refs/heads/master
Commit: 628366cd2e33ebef4ddede67d3ce84663d725f84
Parents: 6fc70b3
Author: Luke Cwik <lc...@google.com>
Authored: Wed Jun 14 20:13:01 2017 -0700
Committer: Luke Cwik <lc...@google.com>
Committed: Thu Jun 15 11:05:03 2017 -0700

----------------------------------------------------------------------
 .../fn-api/src/main/proto/beam_fn_api.proto     | 63 ++++++++++++--------
 1 file changed, 37 insertions(+), 26 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/beam/blob/628366cd/sdks/common/fn-api/src/main/proto/beam_fn_api.proto
----------------------------------------------------------------------
diff --git a/sdks/common/fn-api/src/main/proto/beam_fn_api.proto b/sdks/common/fn-api/src/main/proto/beam_fn_api.proto
index 9fe2b2f..95fe042 100644
--- a/sdks/common/fn-api/src/main/proto/beam_fn_api.proto
+++ b/sdks/common/fn-api/src/main/proto/beam_fn_api.proto
@@ -67,43 +67,47 @@ message Target {
   string name = 2;
 }
 
-// Information defining a PCollection
+// (Deprecated) Information defining a PCollection
+//
+// Migrate to Runner API.
 message PCollection {
   // (Required) A reference to a coder.
-  string coder_reference = 1;
+  string coder_reference = 1 [deprecated = true];
 
   // TODO: Windowing strategy, ...
 }
 
 // A primitive transform within Apache Beam.
 message PrimitiveTransform {
   // (Required) A pipeline level unique id which can be used as a reference to
   // refer to this.
-  string id = 1;
+  string id = 1 [deprecated = true];
 
   // (Required) A function spec that is used by this primitive
   // transform to process data.
-  FunctionSpec function_spec = 2;
+  FunctionSpec function_spec = 2 [deprecated = true];
 
   // A map of distinct input names to target definitions.
   // For example, in CoGbk this represents the tag name associated with each
   // distinct input name and a list of primitive transforms that are associated
   // with the specified input.
-  map<string, Target.List> inputs = 3;
+  map<string, Target.List> inputs = 3 [deprecated = true];
 
   // A map from local output name to PCollection definitions. For example, in
   // DoFn this represents the tag name associated with each distinct output.
-  map<string, PCollection> outputs = 4;
+  map<string, PCollection> outputs = 4 [deprecated = true];
 
   // TODO: Should we model side inputs as a special type of input for a
   // primitive transform or should it be modeled as the relationship that
   // the predecessor input will be a view primitive transform.
   // A map of from side input names to side inputs.
-  map<string, SideInput> side_inputs = 5;
+  map<string, SideInput> side_inputs = 5 [deprecated = true];
 
   // The user name of this step.
   // TODO: This should really be in display data and not at this level
-  string step_name = 6;
+  string step_name = 6 [deprecated = true];
 }
 
 /*
@@ -112,13 +116,14 @@ message PrimitiveTransform {
  * This is still unstable mainly due to how we model the side input.
  */
 
 // Defines the common elements of user-definable functions, to allow the SDK to
 // express the information the runner needs to execute work.
 // Stable
 message FunctionSpec {
   // (Required) A pipeline level unique id which can be used as a reference to
   // refer to this.
-  string id = 1;
+  string id = 1 [deprecated = true];
 
   // (Required) A globally unique name representing this user definable
   // function.
@@ -128,30 +133,31 @@ message FunctionSpec {
   //
   // For example:
   //    urn:org.apache.beam:coder:kv:1.0
-  string urn = 2;
+  string urn = 2 [deprecated = true];
 
   // (Required) Reference to specification of execution environment required to
   // invoke this function.
-  string environment_reference = 3;
+  string environment_reference = 3 [deprecated = true];
 
   // Data used to parameterize this function. Depending on the urn, this may be
   // optional or required.
-  google.protobuf.Any data = 4;
+  google.protobuf.Any data = 4 [deprecated = true];
 }
 
+// (Deprecated) Migrate to Runner API.
 message SideInput {
   // TODO: Coder?
 
   // For RunnerAPI.
-  Target input = 1;
+  Target input = 1 [deprecated = true];
 
   // For FnAPI.
-  FunctionSpec view_fn = 2;
+  FunctionSpec view_fn = 2 [deprecated = true];
 }
 
 // Defines how to encode values into byte streams and decode values from byte
 // streams. A coder can be parameterized by additional properties which may or
 // may not be language agnostic.
 //
 // Coders using the urn:org.apache.beam:coder namespace must have their
 // encodings registered such that another may implement the encoding within
@@ -160,14 +166,15 @@ message SideInput {
 // For example:
 //    urn:org.apache.beam:coder:kv:1.0
 //    urn:org.apache.beam:coder:iterable:1.0
-// Stable
+//
+// Migrate to Runner API.
 message Coder {
   // TODO: This looks weird when compared to the other function specs
   // which use URN to differentiate themselves. Should "Coder" be embedded
   // inside the FunctionSpec data block.
 
   // The data associated with this coder used to reconstruct it.
-  FunctionSpec function_spec = 1;
+  FunctionSpec function_spec = 1 [deprecated = true];
 
   // A list of component coder references.
   //
@@ -180,7 +187,7 @@ message Coder {
   //
   // TODO: Perhaps this is redundant with the data of the FunctionSpec
   // for known coders?
-  repeated string component_coder_reference = 2;
+  repeated string component_coder_reference = 2 [deprecated = true];
 }
 
 // A descriptor for connecting to a remote port using the Beam Fn Data API.
@@ -273,10 +280,14 @@ message ProcessBundleDescriptor {
 
   // (Deprecated) A list of primitive transforms that should
   // be used to construct the bundle processing graph.
-  repeated PrimitiveTransform primitive_transform = 2;
+  //
+  // Migrate to Runner API definitions found within transforms field.
+  repeated PrimitiveTransform primitive_transform = 2 [deprecated = true];
 
   // (Deprecated) The set of all coders referenced in this bundle.
-  repeated Coder coders = 4;
+  //
+  // Migrate to Runner API defintions found within codersyyy field.
+  repeated Coder coders = 4 [deprecated = true];
 
   // (Required) A map from pipeline-scoped id to PTransform.
   map<string, org.apache.beam.runner_api.v1.PTransform> transforms = 5;


[2/2] beam git commit: [BEAM-1348] Mark Runner API like types declared within Fn API as deprecated.

Posted by lc...@apache.org.
[BEAM-1348] Mark Runner API like types declared within Fn API as deprecated.

This closes #3366


Project: http://git-wip-us.apache.org/repos/asf/beam/repo
Commit: http://git-wip-us.apache.org/repos/asf/beam/commit/346a77fa
Tree: http://git-wip-us.apache.org/repos/asf/beam/tree/346a77fa
Diff: http://git-wip-us.apache.org/repos/asf/beam/diff/346a77fa

Branch: refs/heads/master
Commit: 346a77fa8e10e218109cbd100ffc12c35323d66e
Parents: 6fc70b3 628366c
Author: Luke Cwik <lc...@google.com>
Authored: Thu Jun 15 11:05:35 2017 -0700
Committer: Luke Cwik <lc...@google.com>
Committed: Thu Jun 15 11:05:35 2017 -0700

----------------------------------------------------------------------
 .../fn-api/src/main/proto/beam_fn_api.proto     | 63 ++++++++++++--------
 1 file changed, 37 insertions(+), 26 deletions(-)
----------------------------------------------------------------------
@@ -67,43 +67,47 @@ message Target {
 }
 
-// A primitive transform within Apache Beam.
+// (Deprecated) A primitive transform within Apache Beam.
+//
+// Migrate to Runner API.
 message PrimitiveTransform {
   // (Required) A pipeline level unique id which can be used as a reference to
@@ -112,13 +116,14 @@ message PrimitiveTransform {
  */
 
-// Defines the common elements of user-definable functions, to allow the SDK to
-// express the information the runner needs to execute work.
-// Stable
+// (Deprecated) Defines the common elements of user-definable functions,
+// to allow the SDK to express the information the runner needs to execute work.
+//
+// Migrate to Runner API.
 message FunctionSpec {
   // (Required) A pipeline level unique id which can be used as a reference to
@@ -128,30 +133,31 @@ message FunctionSpec {
 }
 
-// Defines how to encode values into byte streams and decode values from byte
-// streams. A coder can be parameterized by additional properties which may or
-// may not be language agnostic.
+// (Deprecated) Defines how to encode values into byte streams and decode
+// values from byte streams. A coder can be parameterized by additional
+// properties which may or may not be language agnostic.
 //
 // Coders using the urn:org.apache.beam:coder namespace must have their